:mod:`langacore.kit.django.common.middleware`
=============================================

.. automodule:: langacore.kit.django.common.middleware


Classes
-------

.. autoclass:: ActivityMiddleware
   :members:

.. autoclass:: AdminForceLanguageCodeMiddleware
   :members:

